@@ -417,7 +417,7 @@ class VideoClip(Clip):
                    filename]
                             
         
-        subprocess_call( cmd )
+        subprocess_call( cmd, verbose = verbose )
         
         for f in tempfiles:
             os.remove(f)
@@ -675,25 +675,6 @@ class VideoClip(Clip):
         
         """
         self.audio = self.audio.fx(fun, *a, **k)
-        
-    #-----------------------------------------------------------------
-    # Previews:
-
-
-
-# Add methods preview and show (only if pygame installed)
-try:
-    from moviepy.video.io.preview import show, preview
-except ImportError:
-    def preview(self, *args, **kwargs):
-        """ NOT AVAILABLE : clip.preview requires Pygame installed  """
-        raise ImportError("clip.preview requires Pygame installed")
-    def show(self, *args, **kwargs):
-        """ NOT AVAILABLE : clip.show requires Pygame installed  """
-        raise ImportError("clip.show requires Pygame installed")
-
-VideoClip.preview = preview
-VideoClip.show = show
 
 
 
@@ -766,13 +747,15 @@ class ImageClip(VideoClip):
                 elif ismask:
                         img = 1.0 * img[:, :, 0] / 255
         
-        # if the image was just a 2D mask, it should arrive here unchanged
+        # if the image was just a 2D mask, it should arrive here
+        # unchanged
         self.get_frame = lambda t: img
         self.size = img.shape[:2][::-1]
         self.img = img
     
     
     
+    
     def fl(self, fl,  apply_to=[], keep_duration=True):
         """ General transformation filter.
         
@@ -788,6 +771,7 @@ class ImageClip(VideoClip):
         return newclip
     
     
+    
     @outplace
     def fl_image(self, image_func, apply_to= []):
         """ Image-transformation filter.
@@ -806,10 +790,11 @@ class ImageClip(VideoClip):
             if hasattr(self, attr):
                 a = getattr(self, attr)
                 if a != None:
-                    new_a =  a.fl(image_func)
+                    new_a =  a.fl_image(image_func)
                     setattr(newclip, attr, new_a)
     
     
+    
     @outplace
     def fl_time(self, time_func, apply_to =['mask', 'audio']):
         """ Time-transformation filter.
@@ -825,9 +810,9 @@ class ImageClip(VideoClip):
             if hasattr(self, attr):
                 a = getattr(self, attr)
                 if a != None:
-                    new_a = a.fl_image(time_func)
+                    new_a = a.fl_time(time_func)
                     setattr(self, attr, new_a)
-
+                    
 
 
 class ColorClip(ImageClip):
