@@ -36,7 +36,7 @@ class FFMPEG_VideoReader:
     def initialize(self, starttime=0):
         """Opens the file, creates the pipe. """
         
-        self.close_proc() # if any
+        self.close() # if any
         
         if starttime !=0 :
             offset = min(1,starttime)
@@ -48,7 +48,8 @@ class FFMPEG_VideoReader:
         
         
         cmd = ([FFMPEG_BINARY]+ i_arg +
-                ['-f', 'image2pipe',
+                ['-loglevel', 'error', 
+                '-f', 'image2pipe',
                 "-pix_fmt", self.pix_fmt,
                 '-vcodec', 'rawvideo', '-'])
         
@@ -117,7 +118,7 @@ class FFMPEG_VideoReader:
             assert len(s) == nbytes
             result = np.fromstring(s,
                              dtype='uint8').reshape((h, w, len(s)//(w*h)))
-            self.proc.stdout.flush()
+            #self.proc.stdout.flush()
             
         except IOError:
             
@@ -155,7 +156,7 @@ class FFMPEG_VideoReader:
             self.pos = pos
             return result
     
-    def close_proc(self):
+    def close(self):
         if self.proc is not None:
             self.proc.terminate()
             self.proc.stdout.close()
@@ -163,7 +164,7 @@ class FFMPEG_VideoReader:
             del self.proc
     
     def __del__(self):
-        self.close_proc()
+        self.close()
         del self.lastread
     
 
